==> digikam-0.10.0.tar.bz2: digikam-0.10.0/libs/themeengine/theme.cpp <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * http://www.digikam.org
 *
 * Date        : 2004-08-02
 * Description : theme manager
 *
 * Copyright (C) 2004 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
 * Copyright (C) 2006-2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#include "theme.h"

// KDE includes.

#include <kdebug.h>


namespace Digikam
{

Theme::Theme(const QString& _name, const QString& _path)
{
    name     = _name;
    filePath = _path;
}

Theme::Theme(const Theme& theme)
{
    if (this != &theme)
    {
        baseColor           =  theme.baseColor;
        textRegColor        =  theme.textRegColor;
        textSelColor        =  theme.textSelColor;
        textSpecialRegColor = theme.textSpecialRegColor;
        textSpecialSelColor = theme.textSpecialSelColor;

        bannerColor         =  theme.bannerColor;
        bannerColorTo       =  theme.bannerColorTo;
        bannerBevel         =  theme.bannerBevel;
        bannerGrad          =  theme.bannerGrad;
        bannerBorder        =  theme.bannerBorder;
        bannerBorderColor   =  theme.bannerBorderColor;

        thumbRegColor       =  theme.thumbRegColor;
        thumbRegColorTo     =  theme.thumbRegColorTo;
        thumbRegBevel       =  theme.thumbRegBevel;
        thumbRegGrad        =  theme.thumbRegGrad;
        thumbRegBorder      =  theme.thumbRegBorder;
        thumbRegBorderColor =  theme.thumbRegBorderColor;

        thumbSelColor       =  theme.thumbSelColor;
        thumbSelColorTo     =  theme.thumbSelColorTo;
        thumbSelBevel       =  theme.thumbSelBevel;
        thumbSelGrad        =  theme.thumbSelGrad;
        thumbSelBorder      =  theme.thumbSelBorder;
        thumbSelBorderColor =  theme.thumbSelBorderColor;

        listRegColor        =  theme.listRegColor;
        listRegColorTo      =  theme.listRegColorTo;
        listRegBevel        =  theme.listRegBevel;
        listRegGrad         =  theme.listRegGrad;
        listRegBorder       =  theme.listRegBorder;
        listRegBorderColor  =  theme.listRegBorderColor;

        listSelColor        =  theme.listSelColor;
        listSelColorTo      =  theme.listSelColorTo;
        listSelBevel        =  theme.listSelBevel;
        listSelGrad         =  theme.listSelGrad;
        listSelBorder       =  theme.listSelBorder;
        listSelBorderColor  =  theme.listSelBorderColor;
    }
}

Theme& Theme::operator=(const Theme& theme)
{
    if (this != &theme)
    {
        baseColor           = theme.baseColor;
        textRegColor        = theme.textRegColor;
        textSelColor        = theme.textSelColor;
        textSpecialRegColor = theme.textSpecialRegColor;
        textSpecialSelColor = theme.textSpecialSelColor;

        bannerColor         = theme.bannerColor;
        bannerColorTo       = theme.bannerColorTo;
        bannerBevel         = theme.bannerBevel;
        bannerGrad          = theme.bannerGrad;
        bannerBorder        = theme.bannerBorder;
        bannerBorderColor   = theme.bannerBorderColor;

        thumbRegColor       = theme.thumbRegColor;
        thumbRegColorTo     = theme.thumbRegColorTo;
        thumbRegBevel       = theme.thumbRegBevel;
        thumbRegGrad        = theme.thumbRegGrad;
        thumbRegBorder      = theme.thumbRegBorder;
        thumbRegBorderColor = theme.thumbRegBorderColor;

        thumbSelColor       = theme.thumbSelColor;
        thumbSelColorTo     = theme.thumbSelColorTo;
        thumbSelBevel       = theme.thumbSelBevel;
        thumbSelGrad        = theme.thumbSelGrad;
        thumbSelBorder      = theme.thumbSelBorder;
        thumbSelBorderColor = theme.thumbSelBorderColor;

        listRegColor        = theme.listRegColor;
        listRegColorTo      = theme.listRegColorTo;
        listRegBevel        = theme.listRegBevel;
        listRegGrad         = theme.listRegGrad;
        listRegBorder       = theme.listRegBorder;
        listRegBorderColor  = theme.listRegBorderColor;

        listSelColor        = theme.listSelColor;
        listSelColorTo      = theme.listSelColorTo;
        listSelBevel        = theme.listSelBevel;
        listSelGrad         = theme.listSelGrad;
        listSelBorder       = theme.listSelBorder;
        listSelBorderColor  = theme.listSelBorderColor;
    }
    return *this;
}

void Theme::print()
{
    /*
    kDebug(50003) << "Theme :                      " << name << endl;

    kDebug(50003) << "Base Color:                  " << baseColor << endl;
    kDebug(50003) << "Text Regular  Color:         " << textRegColor << endl;
    kDebug(50003) << "Text Selected Color:         " << textSelColor << endl;
    kDebug(50003) << "Text Special Regular Color:  " << textSpecialRegColor << endl;
    kDebug(50003) << "Text Special Selected Color: " << textSpecialSelColor << endl;

    kDebug(50003) << "Banner Color:                " << bannerColor << endl;
    kDebug(50003) << "Banner ColorTo :             " << bannerColorTo << endl;
    kDebug(50003) << "Banner Bevel :               " << bannerBevel << endl;
    kDebug(50003) << "Banner Gradient :            " << bannerGrad << endl;
    kDebug(50003) << "Banner Border :              " << bannerBorder << endl;
    kDebug(50003) << "Banner Border Color :        " << bannerBorderColor << endl;

    kDebug(50003) << "ThumbReg Color:              " << thumbRegColor << endl;
    kDebug(50003) << "ThumbReg ColorTo :           " << thumbRegColorTo << endl;
    kDebug(50003) << "ThumbReg Bevel :             " << thumbRegBevel << endl;
    kDebug(50003) << "ThumbReg Gradient :          " << thumbRegGrad << endl;
    kDebug(50003) << "ThumbReg Border :            " << thumbRegBorder << endl;
    kDebug(50003) << "ThumbReg Border Color :      " << thumbRegBorderColor << endl;

    kDebug(50003) << "ThumbSel Color:              " << thumbSelColor << endl;
    kDebug(50003) << "ThumbSel ColorTo :           " << thumbSelColorTo << endl;
    kDebug(50003) << "ThumbSel Bevel :             " << thumbSelBevel << endl;
    kDebug(50003) << "ThumbSel Gradient :          " << thumbSelGrad << endl;
    kDebug(50003) << "ThumbSel Border :            " << thumbSelBorder << endl;
    kDebug(50003) << "ThumbSel Border Color :      " << thumbSelBorderColor << endl;

    kDebug(50003) << "ListReg Color:              " << listRegColor << endl;
    kDebug(50003) << "ListReg ColorTo :           " << listRegColorTo << endl;
    kDebug(50003) << "ListReg Bevel :             " << listRegBevel << endl;
    kDebug(50003) << "ListReg Gradient :          " << listRegGrad << endl;
    kDebug(50003) << "ListReg Border :            " << listRegBorder << endl;
    kDebug(50003) << "ListReg Border Color :      " << listRegBorderColor << endl;

    kDebug(50003) << "ListSel Color:              " << listSelColor << endl;
    kDebug(50003) << "ListSel ColorTo :           " << listSelColorTo << endl;
    kDebug(50003) << "ListSel Bevel :             " << listSelBevel << endl;
    kDebug(50003) << "ListSel Gradient :          " << listSelGrad << endl;
    kDebug(50003) << "ListSel Border :            " << listSelBorder << endl;
    kDebug(50003) << "ListSel Border Color :      " << listSelBorderColor << endl;
    */
}

}  // namespace Digikam

==> digikam-1.5.0.tar.bz2: digikam-1.5.0/libs/themeengine/theme.cpp <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * http://www.digikam.org
 *
 * Date        : 2004-08-02
 * Description : theme manager
 *
 * Copyright (C) 2004 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
 * Copyright (C) 2006-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#include "theme.h"

namespace Digikam
{

Theme::Theme(const QString& n, const QString& p)
{
    name     = n;
    filePath = p;
}

Theme::Theme(const Theme& theme)
{
    if (this != &theme)
    {
        baseColor           = theme.baseColor;
        textRegColor        = theme.textRegColor;
        textSelColor        = theme.textSelColor;
        textSpecialRegColor = theme.textSpecialRegColor;
        textSpecialSelColor = theme.textSpecialSelColor;

        bannerColor         = theme.bannerColor;
        bannerColorTo       = theme.bannerColorTo;
        bannerBevel         = theme.bannerBevel;
        bannerGrad          = theme.bannerGrad;
        bannerBorder        = theme.bannerBorder;
        bannerBorderColor   = theme.bannerBorderColor;

        thumbRegColor       = theme.thumbRegColor;
        thumbRegColorTo     = theme.thumbRegColorTo;
        thumbRegBevel       = theme.thumbRegBevel;
        thumbRegGrad        = theme.thumbRegGrad;
        thumbRegBorder      = theme.thumbRegBorder;
        thumbRegBorderColor = theme.thumbRegBorderColor;

        thumbSelColor       = theme.thumbSelColor;
        thumbSelColorTo     = theme.thumbSelColorTo;
        thumbSelBevel       = theme.thumbSelBevel;
        thumbSelGrad        = theme.thumbSelGrad;
        thumbSelBorder      = theme.thumbSelBorder;
        thumbSelBorderColor = theme.thumbSelBorderColor;

        listRegColor        = theme.listRegColor;
        listRegColorTo      = theme.listRegColorTo;
        listRegBevel        = theme.listRegBevel;
        listRegGrad         = theme.listRegGrad;
        listRegBorder       = theme.listRegBorder;
        listRegBorderColor  = theme.listRegBorderColor;

        listSelColor        = theme.listSelColor;
        listSelColorTo      = theme.listSelColorTo;
        listSelBevel        = theme.listSelBevel;
        listSelGrad         = theme.listSelGrad;
        listSelBorder       = theme.listSelBorder;
        listSelBorderColor  = theme.listSelBorderColor;
    }
}

Theme& Theme::operator=(const Theme& theme)
{
    if (this != &theme)
    {
        baseColor           = theme.baseColor;
        textRegColor        = theme.textRegColor;
        textSelColor        = theme.textSelColor;
        textSpecialRegColor = theme.textSpecialRegColor;
        textSpecialSelColor = theme.textSpecialSelColor;

        bannerColor         = theme.bannerColor;
        bannerColorTo       = theme.bannerColorTo;
        bannerBevel         = theme.bannerBevel;
        bannerGrad          = theme.bannerGrad;
        bannerBorder        = theme.bannerBorder;
        bannerBorderColor   = theme.bannerBorderColor;

        thumbRegColor       = theme.thumbRegColor;
        thumbRegColorTo     = theme.thumbRegColorTo;
        thumbRegBevel       = theme.thumbRegBevel;
        thumbRegGrad        = theme.thumbRegGrad;
        thumbRegBorder      = theme.thumbRegBorder;
        thumbRegBorderColor = theme.thumbRegBorderColor;

        thumbSelColor       = theme.thumbSelColor;
        thumbSelColorTo     = theme.thumbSelColorTo;
        thumbSelBevel       = theme.thumbSelBevel;
        thumbSelGrad        = theme.thumbSelGrad;
        thumbSelBorder      = theme.thumbSelBorder;
        thumbSelBorderColor = theme.thumbSelBorderColor;

        listRegColor        = theme.listRegColor;
        listRegColorTo      = theme.listRegColorTo;
        listRegBevel        = theme.listRegBevel;
        listRegGrad         = theme.listRegGrad;
        listRegBorder       = theme.listRegBorder;
        listRegBorderColor  = theme.listRegBorderColor;

        listSelColor        = theme.listSelColor;
        listSelColorTo      = theme.listSelColorTo;
        listSelBevel        = theme.listSelBevel;
        listSelGrad         = theme.listSelGrad;
        listSelBorder       = theme.listSelBorder;
        listSelBorderColor  = theme.listSelBorderColor;
    }
    return *this;
}

void Theme::print()
{
/*
    kDebug() << "Theme :                      " << name;

    kDebug() << "Base Color:                  " << baseColor;
    kDebug() << "Text Regular  Color:         " << textRegColor;
    kDebug() << "Text Selected Color:         " << textSelColor;
    kDebug() << "Text Special Regular Color:  " << textSpecialRegColor;
    kDebug() << "Text Special Selected Color: " << textSpecialSelColor;

    kDebug() << "Banner Color:                " << bannerColor;
    kDebug() << "Banner ColorTo :             " << bannerColorTo;
    kDebug() << "Banner Bevel :               " << bannerBevel;
    kDebug() << "Banner Gradient :            " << bannerGrad;
    kDebug() << "Banner Border :              " << bannerBorder;
    kDebug() << "Banner Border Color :        " << bannerBorderColor;

    kDebug() << "ThumbReg Color:              " << thumbRegColor;
    kDebug() << "ThumbReg ColorTo :           " << thumbRegColorTo;
    kDebug() << "ThumbReg Bevel :             " << thumbRegBevel;
    kDebug() << "ThumbReg Gradient :          " << thumbRegGrad;
    kDebug() << "ThumbReg Border :            " << thumbRegBorder;
    kDebug() << "ThumbReg Border Color :      " << thumbRegBorderColor;

    kDebug() << "ThumbSel Color:              " << thumbSelColor;
    kDebug() << "ThumbSel ColorTo :           " << thumbSelColorTo;
    kDebug() << "ThumbSel Bevel :             " << thumbSelBevel;
    kDebug() << "ThumbSel Gradient :          " << thumbSelGrad;
    kDebug() << "ThumbSel Border :            " << thumbSelBorder;
    kDebug() << "ThumbSel Border Color :      " << thumbSelBorderColor;

    kDebug() << "ListReg Color:              " << listRegColor;
    kDebug() << "ListReg ColorTo :           " << listRegColorTo;
    kDebug() << "ListReg Bevel :             " << listRegBevel;
    kDebug() << "ListReg Gradient :          " << listRegGrad;
    kDebug() << "ListReg Border :            " << listRegBorder;
    kDebug() << "ListReg Border Color :      " << listRegBorderColor;

    kDebug() << "ListSel Color:              " << listSelColor;
    kDebug() << "ListSel ColorTo :           " << listSelColorTo;
    kDebug() << "ListSel Bevel :             " << listSelBevel;
    kDebug() << "ListSel Gradient :          " << listSelGrad;
    kDebug() << "ListSel Border :            " << listSelBorder;
    kDebug() << "ListSel Border Color :      " << listSelBorderColor;
*/
}

}  // namespace Digikam
